#ifndef NT2_INCLUDE_CONSTANTS_THIRD_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_THIRD_HPP_INCLUDED

#include <nt2/constant/include/constants/third.hpp>

#endif
